"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getElementAttrs = exports.getComponentNames = exports.getTemplateContextProps = exports.getComponentEvents = exports.getComponentProps = exports.getQuickInfoAtPosition = exports.getPropertiesAtLocation = exports.collectExtractProps = void 0;
const net = require("net");
const fs = require("fs");
const utils_1 = require("./utils");
function collectExtractProps(...args) {
    return sendRequest({
        type: 'collectExtractProps',
        args,
    });
}
exports.collectExtractProps = collectExtractProps;
async function getPropertiesAtLocation(...args) {
    return await sendRequest({
        type: 'getPropertiesAtLocation',
        args,
    });
}
exports.getPropertiesAtLocation = getPropertiesAtLocation;
function getQuickInfoAtPosition(...args) {
    return sendRequest({
        type: 'getQuickInfoAtPosition',
        args,
    });
}
exports.getQuickInfoAtPosition = getQuickInfoAtPosition;
// Component Infos
function getComponentProps(...args) {
    return sendRequest({
        type: 'getComponentProps',
        args,
    });
}
exports.getComponentProps = getComponentProps;
function getComponentEvents(...args) {
    return sendRequest({
        type: 'getComponentEvents',
        args,
    });
}
exports.getComponentEvents = getComponentEvents;
function getTemplateContextProps(...args) {
    return sendRequest({
        type: 'getTemplateContextProps',
        args,
    });
}
exports.getTemplateContextProps = getTemplateContextProps;
function getComponentNames(...args) {
    return sendRequest({
        type: 'getComponentNames',
        args,
    });
}
exports.getComponentNames = getComponentNames;
function getElementAttrs(...args) {
    return sendRequest({
        type: 'getElementAttrs',
        args,
    });
}
exports.getElementAttrs = getElementAttrs;
async function sendRequest(request) {
    const pipeFile = await getPipeFile(request.args[0]);
    if (!pipeFile) {
        console.error('[Vue Named Pipe Client] pipeFile not found');
        return;
    }
    return await _sendRequest(request, pipeFile);
}
async function getPipeFile(fileName) {
    if (fs.existsSync(utils_1.pipeTable)) {
        const table = JSON.parse(fs.readFileSync(utils_1.pipeTable, 'utf8'));
        const all = Object.values(table);
        const configuredServers = all
            .filter(item => item.serverKind === 1)
            .sort((a, b) => Math.abs(process.pid - a.pid) - Math.abs(process.pid - b.pid));
        const inferredServers = all
            .filter(item => item.serverKind === 0)
            .sort((a, b) => Math.abs(process.pid - a.pid) - Math.abs(process.pid - b.pid));
        for (const server of configuredServers) {
            const response = await _sendRequest({ type: 'containsFile', args: [fileName] }, server.pipeFile);
            if (response) {
                return server.pipeFile;
            }
        }
        for (const server of inferredServers) {
            const response = await _sendRequest({ type: 'containsFile', args: [fileName] }, server.pipeFile);
            if (typeof response === 'boolean') {
                return server.pipeFile;
            }
        }
    }
}
function _sendRequest(request, pipeFile) {
    return new Promise(resolve => {
        try {
            const client = net.connect(pipeFile);
            client.on('connect', () => {
                client.write(JSON.stringify(request));
            });
            client.on('data', data => {
                const text = data.toString();
                resolve(JSON.parse(text));
                client.end();
            });
            client.on('error', err => {
                console.error('[Vue Named Pipe Client]', err);
                return resolve(undefined);
            });
        }
        catch (e) {
            console.error('[Vue Named Pipe Client]', e);
            return resolve(undefined);
        }
    });
}
//# sourceMappingURL=client.js.map